@@ -271,7 +271,7 @@ class EventName(StrEnum):
     CONDITION_GROUP_DELETED = "ConditionGroupDeletedEvent"
     CONDITION_GROUP_UPDATED = "ConditionGroupUpdatedEvent"
     DELAYED_TRIGGER_CANCELLED = "DelayedTriggerCancelledEvent"
-    DELAYED_TRIGGER_SET_EVENT = "DelayedTriggerSetEvent"
+    DELAYED_TRIGGER_SET = "DelayedTriggerSetEvent"
     DEVICE_ATTRIBUTE_CHANGED = "DeviceAttributeChangedEvent"
     DEVICE_AVAILABLE = "DeviceAvailableEvent"
     DEVICE_CREATED = "DeviceCreatedEvent"
@@ -324,6 +324,7 @@ class EventName(StrEnum):
     GATEWAY_DETACHED = "GatewayDetachedEvent"
     GATEWAY_DISSOCIATED = "GatewayDissociatedEvent"
     GATEWAY_DOWN = "GatewayDownEvent"
+    GATEWAY_DOWN_OPTIONS_CHANGED = "GatewayDownOptionsChangedEvent"
     GATEWAY_FIRMWARE_UPDATED = "GatewayFirmwareUpdatedEvent"
     GATEWAY_FIRMWARE_UPDATE_COMPLETED = "GatewayFirmwareUpdateCompletedEvent"
     GATEWAY_FUNCTION_CHANGED = "GatewayFunctionChangedEvent"
@@ -367,6 +368,7 @@ class EventName(StrEnum):
     SECONDARY_ACCOUNT_UPDATED = "SecondaryAccountUpdatedEvent"
     SETUP_JOB_COMPLETED = "SetupJobCompletedEvent"
     SETUP_JOB_FAILED = "SetupJobFailedEvent"
+    SETUP_METADATA_UPDATED = "SetupMetadataUpdatedEvent"
     SETUP_QUOTA_UPDATED = "SetupQuotaUpdatedEvent"
     SETUP_TRIGGER_CREATED = "SetupTriggerCreatedEvent"
     SETUP_TRIGGER_CREATION_FAILED = "SetupTriggerCreationFailedEvent"
@@ -407,6 +409,10 @@ class EventName(StrEnum):
     TOKEN_DELETION_FAILED = "TokenDeletionFailedEvent"
     TOKEN_REMOVED = "TokenRemovedEvent"
     TRIGGER_EXPIRED = "TriggerExpiredEvent"
+    NETATMO_CURRENT_TOKEN_COMPLETED = "NetatmoCurrentTokenCompletedEvent"
+    NETATMO_CURRENT_TOKEN_FAILED = "NetatmoCurrentTokenFailedEvent"
+    NETATMO_REFRESH_CURRENT_TOKEN_COMPLETED = "NetatmoRefreshCurrentTokenCompletedEvent"
+    NETATMO_REFRESH_CURRENT_TOKEN_FAILED = "NetatmoRefreshCurrentTokenFailedEvent"
     UNPN_CONTROL_CURRENT_ACTIONS = "UPnPControlCurrentActionsEvent"
     UNPN_CONTROL_GROUP_MUTE_STATUS = "UPnPControlGroupMuteStatusEvent"
     UNPN_CONTROL_GROUP_VOLUME = "UPnPControlGroupVolumeEvent"
