@@ -20,34 +20,37 @@ class Protocol(StrEnum):
     """
 
     UNKNOWN = "unknown"
-    IO = "io"
-    RTS = "rts"
-    RTD = "rtd"
-    RTDS = "rtds"
-    RAMSES = "ramses"
-    ENOCEAN = "enocean"
-    ZWAVE = "zwave"
+
+    AUGUST = "august"
     CAMERA = "camera"
-    OVP = "ovp"
+    ELIOT = "eliot"
+    ENOCEAN = "enocean"
+    HLRR_WIFI = "hlrrwifi"
+    HOMEKIT = "homekit"
+    HUE = "hue"
+    INTERNAL = "internal"
+    IO = "io"
+    JSW = "jsw"
     MODBUS = "modbus"
     MODBUSLINK = "modbuslink"
-    HUE = "hue"
-    VERISURE = "verisure"
-    INTERNAL = "internal"
-    JSW = "jsw"
-    OPENDOORS = "opendoors"
     MYFOX = "myfox"
-    SOMFY_THERMOSTAT = "somfythermostat"
-    ZIGBEE = "zigbee"
-    UPNP_CONTROL = "upnpcontrol"
-    ELIOT = "eliot"
-    WISER = "wiser"
-    PROFALUX_868 = "profalux868"
+    NETATMO = "netatmo"
+    OGCP = "ogcp"
     OGP = "ogp"
-    HOMEKIT = "homekit"
-    AUGUST = "august"
-    HLRR_WIFI = "hlrrwifi"
+    OPENDOORS = "opendoors"
+    OVP = "ovp"
+    PROFALUX_868 = "profalux868"
+    RAMSES = "ramses"
+    RTD = "rtd"
+    RTDS = "rtds"
     RTN = "rtn"
+    RTS = "rts"
+    SOMFY_THERMOSTAT = "somfythermostat"
+    UPNP_CONTROL = "upnpcontrol"
+    VERISURE = "verisure"
+    WISER = "wiser"
+    ZIGBEE = "zigbee"
+    ZWAVE = "zwave"
 
     @classmethod
     def _missing_(cls, value):  # type: ignore
