@@ -33,6 +33,15 @@ class OverkizAttribute(StrEnum):
 class OverkizState(StrEnum):
     """Device states used by Overkiz."""
 
+    CORE_ABSENCE_COOLING_TARGET_TEMPERATURE = (
+        "core:AbsenceCoolingTargetTemperatureState"
+    )
+    CORE_ABSENCE_END_DATE_TIME = "core:AbsenceEndDateTimeState"
+    CORE_ABSENCE_HEATING_TARGET_TEMPERATURE = (
+        "core:AbsenceHeatingTargetTemperatureState"
+    )
+    CORE_ACTIVE_COOLING_TIME_PROGRAM = "core:ActiveCoolingTimeProgramState"
+    CORE_ACTIVE_HEATING_TIME_PROGRAM = "core:ActiveHeatingTimeProgramState"
     CORE_ACTIVE_ZONES = "core:ActiveZonesState"
     CORE_ACTIVATED_OPTIONS = "core:ActivatedOptionsState"
     CORE_ASSEMBLY = "core:AssemblyState"
@@ -40,6 +49,7 @@ class OverkizState(StrEnum):
     CORE_AVAILABILITY = "core:AvailabilityState"
     CORE_BATTERY = "core:BatteryState"
     CORE_BATTERY_LEVEL = "core:BatteryLevelState"
+    CORE_BATTERY_DISCRETE_LEVEL = "core:BatteryDiscreteLevelState"
     CORE_BLUE_COLOR_INTENSITY = "core:BlueColorIntensityState"
     CORE_BOOST_ELECTRIC_POWER_CONSUMPTION = "core:BoostElectricPowerConsumptionState"
     CORE_BOOST_END_DATE = "core:BoostEndDateState"
@@ -51,6 +61,10 @@ class OverkizState(StrEnum):
     CORE_CLOSURE_OR_ROCKER_POSITION = "core:ClosureOrRockerPositionState"
     CORE_CLOUD_DEVICE_STATUS = "core:CloudDeviceStatusState"
     CORE_CO2_CONCENTRATION = "core:CO2ConcentrationState"
+    CORE_COMMAND_LOCK_LEVELS = "core:CommandLockLevelsState"
+    CORE_COMFORT_COOLING_TARGET_TEMPERATURE = (
+        "core:ComfortCoolingTargetTemperatureState"
+    )
     CORE_COMFORT_HEATING_TARGET_TEMPERATURE = (
         "core:ComfortHeatingTargetTemperatureState"
     )
@@ -68,14 +82,19 @@ class OverkizState(StrEnum):
     CORE_CONTACT = "core:ContactState"
     CORE_CONTROL_WATER_TARGET_TEMPERATURE = "core:ControlWaterTargetTemperatureState"
     CORE_CO_CONCENTRATION = "core:COConcentrationState"
+    CORE_COOLING_ON_OFF = "core:CoolingOnOffState"
+    CORE_COOLING_TARGET_TEMPERATURE = "core:CoolingTargetTemperatureState"
+    CORE_DATETIME = "core:DateTimeState"
     CORE_DEPLOYMENT = "core:DeploymentState"
     CORE_DEROGATED_TARGET_TEMPERATURE = "core:DerogatedTargetTemperatureState"
     CORE_DEROGATION_ACTIVATION = "core:DerogationActivationState"
     CORE_DEROGATION_ON_OFF = "core:DerogationOnOffState"
+    CORE_DEVICE_SERIAL_NUMBER = "core:DeviceSerialNumberState"
     CORE_DHW_DEROGATION_AVAILABILITY = "core:DHWDerogationAvailabilityState"
     CORE_DHW_TEMPERATURE = "core:DHWTemperatureState"
     CORE_DISCRETE_RSSI_LEVEL = "core:DiscreteRSSILevelState"
     CORE_DWH_ON_OFF = "core:DHWOnOffState"
+    CORE_ECO_COOLING_TARGET_TEMPERATURE = "core:EcoCoolingTargetTemperatureState"
     CORE_ECO_HEATING_TARGET_TEMPERATURE = "core:EcoHeatingTargetTemperatureState"
     CORE_ECO_ROOM_TEMPERATURE = "core:EcoRoomTemperatureState"
     CORE_ECO_TARGET_DWH_TEMPERATURE = "core:EcoTargetDHWTemperatureState"
@@ -88,6 +107,8 @@ class OverkizState(StrEnum):
     CORE_GAS_DETECTION = "core:GasDetectionState"
     CORE_GREEN_COLOR_INTENSITY = "core:GreenColorIntensityState"
     CORE_HOLIDAYS_MODE = "core:HolidaysModeState"
+    CORE_HEATING_COOLING_AUTO_SWITCH = "core:HeatingCoolingAutoSwitchState"
+    CORE_HEATING_DEROGATION_AVAILABILITY = "core:HeatingDerogationAvailabilityState"
     CORE_HEATING_ON_OFF = "core:HeatingOnOffState"
     CORE_HEATING_STATUS = "core:HeatingStatusState"
     CORE_HEATING_TARGET_TEMPERATURE = "core:HeatingTargetTemperatureState"
@@ -95,12 +116,17 @@ class OverkizState(StrEnum):
     CORE_LEVEL = "core:LevelState"
     CORE_LIGHT_INTENSITY = "core:LightIntensityState"
     CORE_LOCKED_UNLOCKED = "core:LockedUnlockedState"
+    CORE_LOWER_CLOSURE = "core:LowerClosureState"
+    CORE_LOWER_OPEN_CLOSED = "core:LowerOpenClosedState"
     CORE_LUMINANCE = "core:LuminanceState"
     CORE_MANUFACTURER_NAME = "core:ManufacturerNameState"
     CORE_MIN_SETPOINT = "core:MinSetpointState"
     CORE_MAX_SETPOINT = "core:MaxSetpointState"
     CORE_MAXIMAL_SHOWER_MANUAL_MODE = "core:MaximalShowerManualModeState"
     CORE_MAXIMAL_TEMPERATURE_MANUAL_MODE = "core:MaximalTemperatureManualModeState"
+    CORE_MAXIMUM_COOLING_TARGET_TEMPERATURE = (
+        "core:MaximumCoolingTargetTemperatureState"
+    )
     CORE_MAXIMUM_HEATING_TARGET_TEMPERATURE = (
         "core:MaximumHeatingTargetTemperatureState"
     )
@@ -109,6 +135,9 @@ class OverkizState(StrEnum):
     CORE_MIDDLE_WATER_TEMPERATURE_IN = "core:MiddleWaterTemperatureInState"
     CORE_MINIMAL_SHOWER_MANUAL_MODE = "core:MinimalShowerManualModeState"
     CORE_MINIMAL_TEMPERATURE_MANUAL_MODE = "core:MinimalTemperatureManualModeState"
+    CORE_MINIMUM_COOLING_TARGET_TEMPERATURE = (
+        "core:MinimumCoolingTargetTemperatureState"
+    )
     CORE_MINIMUM_HEATING_TARGET_TEMPERATURE = (
         "core:MinimumHeatingTargetTemperatureState"
     )
@@ -135,9 +164,11 @@ class OverkizState(StrEnum):
     CORE_PROGRAMMING_AVAILABLE = "core:ProgrammingAvailableState"
     CORE_RAIN = "core:RainState"
     CORE_RED_COLOR_INTENSITY = "core:RedColorIntensityState"
+    CORE_REGULATION_MODE = "core:RegulationModeState"
     CORE_RELATIVE_HUMIDITY = "core:RelativeHumidityState"
     CORE_REMAINING_HOT_WATER = "core:RemainingHotWaterState"
     CORE_RSSI_LEVEL = "core:RSSILevelState"
+    CORE_SECURED_POSITION = "core:SecuredPositionState"
     CORE_SECURED_POSITION_TEMPERATURE = "core:SecuredPositionTemperatureState"
     CORE_SENSOR_DEFECT = "core:SensorDefectState"
     CORE_SLATE_ORIENTATION = "core:SlateOrientationState"
@@ -154,6 +185,12 @@ class OverkizState(StrEnum):
     CORE_THERMAL_CONFIGURATION = "core:ThermalConfigurationState"
     CORE_THERMAL_ENERGY_CONSUMPTION = "core:ThermalEnergyConsumptionState"
     CORE_THREE_WAY_HANDLE_DIRECTION = "core:ThreeWayHandleDirectionState"
+    CORE_TIME_PROGRAM_1 = "core:TimeProgram1State"
+    CORE_TIME_PROGRAM_2 = "core:TimeProgram2State"
+    CORE_TIME_PROGRAM_3 = "core:TimeProgram3State"
+    CORE_TIME_PROGRAM_4 = "core:TimeProgram4State"
+    CORE_UPPER_CLOSURE = "core:UpperClosureState"
+    CORE_UPPER_OPEN_CLOSED = "core:UpperOpenClosedState"
     CORE_V40_WATER_VOLUME_ESTIMATION = "core:V40WaterVolumeEstimationState"
     CORE_VIBRATION = "core:VibrationState"
     CORE_WATER_CONSUMPTION = "core:WaterConsumptionState"
@@ -161,6 +198,7 @@ class OverkizState(StrEnum):
     CORE_WATER_TARGET_TEMPERATURE = "core:WaterTargetTemperatureState"
     CORE_WEATHER_STATUS = "core:WeatherStatusState"
     CORE_WIND_SPEED = "core:WindSpeedState"
+    CORE_ZONE_NUMBER = "core:ZonesNumberState"
     HLRRWIFI_FAN_SPEED = "hlrrwifi:FanSpeedState"
     HLRRWIFI_LEAVE_HOME = "hlrrwifi:LeaveHomeState"
     HLRRWIFI_MAIN_OPERATION = "hlrrwifi:MainOperationState"
@@ -171,6 +209,8 @@ class OverkizState(StrEnum):
     INTERNAL_CURRENT_ALARM_MODE = "internal:CurrentAlarmModeState"
     INTERNAL_INTRUSION_DETECTED = "internal:IntrusionDetectedState"
     INTERNAL_TARGET_ALARM_MODE = "internal:TargetAlarmModeState"
+    IO_ABSENCE_SCHEDULING_AVAILABILITY = "io:AbsenceSchedulingAvailabilityState"
+    IO_ABSENCE_SCHEDULING_MODE = "io:AbsenceSchedulingModeState"
     IO_AIR_DEMAND_MODE = "io:AirDemandModeState"
     IO_AWAY_MODE_DURATION = "io:AwayModeDurationState"
     IO_BYPASS_ACTIVATION = "io:ByPassActivationState"
@@ -184,6 +224,7 @@ class OverkizState(StrEnum):
     IO_FORCE_HEATING = "io:ForceHeatingState"
     IO_HEAT_PUMP_OPERATING_TIME = "io:HeatPumpOperatingTimeState"
     IO_INLET_ENGINE = "io:InletEngineState"
+    IO_LAST_PASS_APC_OPERATING_MODE = "io:LastPassAPCOperatingModeState"
     IO_LOCK_KEY_ACTIVATION = "io:LockKeyActivationState"
     IO_MEMORIZED_SIMPLE_VOLUME = "io:MemorizedSimpleVolumeState"
     IO_MIDDLE_WATER_TEMPERATURE = "io:MiddleWaterTemperatureState"
@@ -193,13 +234,20 @@ class OverkizState(StrEnum):
     IO_PASS_APCDHW_CONFIGURATION = "io:PassAPCDHWConfigurationState"
     IO_PASS_APCDHW_PROFILE = "io:PassAPCDHWProfileState"
     IO_PASS_APCDWH_MODE = "io:PassAPCDHWModeState"
+    IO_PASS_APC_COOLING_MODE = "io:PassAPCCoolingModeState"
+    IO_PASS_APC_COOLING_PROFILE = "io:PassAPCCoolingProfileState"
     IO_PASS_APC_HEATING_MODE = "io:PassAPCHeatingModeState"
     IO_PASS_APC_HEATING_PROFILE = "io:PassAPCHeatingProfileState"
     IO_PASS_APC_OPERATING_MODE = "io:PassAPCOperatingModeState"
+    IO_PASS_APC_PRODUCT_TYPE = "io:PassAPCProductTypeState"
+    IO_POWER_HEAT_ELECTRICAL = "io:PowerHeatElectricalState"
+    IO_POWER_HEAT_PUMP = "io:PowerHeatPumpState"
     IO_PRIORITY_LOCK_LEVEL = "io:PriorityLockLevelState"
     IO_PRIORITY_LOCK_ORIGINATOR = "io:PriorityLockOriginatorState"
     IO_SENSOR_ROOM = "io:SensorRoomState"
     IO_TARGET_HEATING_LEVEL = "io:TargetHeatingLevelState"
+    IO_THERMAL_SCHEDULING_AVAILABILITY = "io:ThermalSchedulingAvailabilityState"
+    IO_THERMAL_SCHEDULING_MODE = "io:ThermalSchedulingModeState"
     IO_TOWEL_DRYER_TEMPORARY_STATE = "io:TowelDryerTemporaryStateState"
     IO_VALVE_INSTALLATION_MODE = "io:ValveInstallationModeState"
     IO_VENTILATION_CONFIGURATION_MODE = "io:VentilationConfigurationModeState"
@@ -226,9 +274,93 @@ class OverkizState(StrEnum):
     MODBUSLINK_POWER_HEAT_PUMP = "modbuslink:PowerHeatPumpState"
     MODBUSLINK_PROGRAMMING_SLOTS = "modbuslink:ProgrammingSlotsState"
     MODBUSLINK_SMART_GRID_OPTION = "modbuslink:SmartGridOptionState"
+    MODBUS_ALARM_NUMBER = "modbus:AlarmNumberState"
+    MODBUS_AUTO_MANU_MODE_ZONE_1 = "modbus:AutoManuModeZone1State"
+    MODBUS_CAUSE_OF_STOPPAGE = "modbus:CauseOfStoppageState"
+    MODBUS_CENTRAL_SETTING_1 = "modbus:CentralSetting1State"
+    MODBUS_CENTRAL_SETTING_2 = "modbus:CentralSetting2State"
+    MODBUS_CENTRAL_SETTING_3 = "modbus:CentralSetting3State"
+    MODBUS_COMPRESSOR_CURRENT_VALUE = "modbus:CompressorCurrentValueState"
+    MODBUS_COMPRESSOR_FREQUENCY = "modbus:CompressorFrequencyState"
+    MODBUS_COMPRESSOR_RUNNING_CURRENT = "modbus:CompressorRunningCurrentState"
+    MODBUS_CONTROL_BLOCK_MENU = "modbus:ControlBlockMenuState"
+    MODBUS_CONTROL_COMMUNICATION_ALARM_BIT = "modbus:ControlCommunicationAlarmBitState"
     MODBUS_CONTROL_DHW = "modbus:ControlDHWState"
     MODBUS_CONTROL_DHW_SETTING_TEMPERATURE = "modbus:ControlDHWSettingTemperatureState"
+    MODBUS_CONTROL_UNIT = "modbus:ControlUnitState"
+    MODBUS_CONTROL_UNIT_MODE = "modbus:ControlUnitModeState"
+    MODBUS_DEFROSTING = "modbus:DefrostingState"
     MODBUS_DHW_MODE = "modbus:DHWModeState"
+    MODBUS_DISCHARGE_GAS_TEMPERATURE = "modbus:DischargeGasTemperatureState"
+    MODBUS_DISCHARGE_PRESSURE = "modbus:DischargePressureState"
+    MODBUS_DISCHARGE_TEMPERATURE = "modbus:DischargeTemperatureState"
+    MODBUS_ECO_MODE_OFFSET = "modbus:EcoModeOffsetState"
+    MODBUS_ECO_MODE_OFFSET_TARGET = "modbus:EcoModeOffsetTargetState"
+    MODBUS_EVAPORATING_TEMPERATURE = "modbus:EvaporatingTemperatureState"
+    MODBUS_EVAPORATION_TEMPERATURE = "modbus:EvaporationTemperatureState"
+    MODBUS_GAS_TEMPERATURE = "modbus:GasTemperatureState"
+    MODBUS_HARDWARE_VERSION = "modbus:HardwareVersionState"
+    MODBUS_HLINK_COMMUNICATION_ALARM = "modbus:HLinkCommunicationAlarmState"
+    MODBUS_INDOOR_EXPANSION_VALVE = "modbus:IndoorExpansionValveState"
+    MODBUS_INDOOR_EXPANSION_VALVE_OPENING = "modbus:IndoorExpansionValveOpeningState"
+    MODBUS_INVERTER_OPERATION_FREQUENCY = "modbus:InverterOperationFrequencyState"
+    MODBUS_LCD_CENTRAL_MODE = "modbus:LCDCentralModeState"
+    MODBUS_LCD_SOFTWARE_NUMBER = "modbus:LCDSoftwareNumberState"
+    MODBUS_LIQUID_TEMPERATURE = "modbus:LiquidTemperatureState"
+    MODBUS_LIQUID_TEMPERATURE_THMI = "modbus:LiquidTemperatureTHMIState"
+    MODBUS_MIXING_VALVE_POSITION = "modbus:MixingValvePositionState"
+    MODBUS_OPERATION = "modbus:OperationState"
+    MODBUS_OUTDOOR_AMBIENT_TEMPERATURE = "modbus:OutdoorAmbientTemperatureState"
+    MODBUS_OUTDOOR_EXPANSION_VALVE = "modbus:OutdoorExpansionValveState"
+    MODBUS_OUTDOOR_UNIT_AMBIENT = "modbus:OutdoorUnitAmbientState"
+    MODBUS_PCB1_SOFTWARE_NUMBER = "modbus:PCB1SoftwareNumberState"
+    MODBUS_PRODUCT_SPEC_CODE = "modbus:ProductSpecCodeState"
+    MODBUS_RETRY_CODE = "modbus:RetryCodeState"
+    MODBUS_ROOM_AMBIENT_TEMPERATURE_STATUS_ZONE_1 = (
+        "modbus:RoomAmbientTemperatureStatusZone1State"
+    )
+    MODBUS_ROOM_THERMOSTAT_SET_TEMPERATURE_C1 = (
+        "modbus:RoomThermostatSetTemperatureC1State"
+    )
+    MODBUS_ROOM_THERMOSTAT_SET_TEMPERATURE_C2 = (
+        "modbus:RoomThermostatSetTemperatureC2State"
+    )
+    MODBUS_ROOM_THERMOSTAT_TEMPERATURE_C1 = "modbus:RoomThermostatTemperatureC1State"
+    MODBUS_ROOM_THERMOSTAT_TEMPERATURE_C2 = "modbus:RoomThermostatTemperatureC2State"
+    MODBUS_SECOND_AMBIENT_AVERAGE_TEMPERATURE = (
+        "modbus:SecondAmbientAverageTemperatureState"
+    )
+    MODBUS_SECOND_AMBIENT_TEMPERATURE = "modbus:SecondAmbientTemperatureState"
+    MODBUS_SOFTWARE_NUMBER = "modbus:SoftwareNumberState"
+    MODBUS_SOFTWARE_VERSION = "modbus:SoftwareVersionState"
+    MODBUS_SPACE_MODE = "modbus:SpaceModeState"
+    MODBUS_STATUS_BLOCK_MENU = "modbus:StatusBlockMenuState"
+    MODBUS_STATUS_COMMUNICATION_ALARM_BIT = "modbus:StatusCommunicationAlarmBitState"
+    MODBUS_STATUS_UNIT_MODE = "modbus:StatusUnitModeState"
+    MODBUS_SUCTION_PRESSURE = "modbus:SuctionPressureState"
+    MODBUS_SUCTION_TEMPERATURE = "modbus:SuctionTemperatureState"
+    MODBUS_SYSTEM_CONFIGURATION = "modbus:SystemConfigurationState"
+    MODBUS_SYSTEM_STATUS_2 = "modbus:SystemStatus2State"
+    MODBUS_TAHOMA_ROOM_THERMOSTAT_AVAILABLE = (
+        "modbus:TahomaRoomThermostatAvailableState"
+    )
+    MODBUS_THERMOSTAT_SETTING_CONTROL_ZONE_1 = (
+        "modbus:ThermostatSettingControlZone1State"
+    )
+    MODBUS_THERMOSTAT_SETTING_STATUS_ZONE_1 = "modbus:ThermostatSettingStatusZone1State"
+    MODBUS_UNIT_MODEL = "modbus:UnitModelState"
+    MODBUS_VIRTUAL_ECO_COMFORT_MODE = "modbus:VirtualEcoComfortModeState"
+    MODBUS_WATER_FLOW_LEVEL = "modbus:WaterFlowLevelState"
+    MODBUS_WATER_INLET_UNIT_TEMPERATURE = "modbus:WaterInletUnitTemperatureState"
+    MODBUS_WATER_OUTLET_HP_TEMPERATURE = "modbus:WaterOutletHpTemperatureState"
+    MODBUS_WATER_OUTLET_TEMPERATURE_2 = "modbus:WaterOutletTemperature2State"
+    MODBUS_WATER_OUTLET_TEMPERATURE_3 = "modbus:WaterOutletTemperature3State"
+    MODBUS_WATER_OUTLET_UNIT_TEMPERATURE = "modbus:WaterOutletUnitTemperatureState"
+    MODBUS_WATER_PUMP_SPEED = "modbus:WaterPumpSpeedState"
+    MODBUS_WATER_TEMPERATURE_SETTING = "modbus:WaterTemperatureSettingState"
+    MODBUS_YUTAKI_TARGET_MODE = "modbus:YutakiTargetModeState"
+    MODBUS_YUTAKI_VIRTUAL_OPERATING_MODE = "modbus:YutakiVirtualOperatingModeState"
+
     MYFOX_ALARM_STATUS = "myfox:AlarmStatusState"
     MYFOX_ALERT_TRESPASS = "myfox:AlertTrespassState"
     MYFOX_SHUTTER_STATUS = "myfox:ShutterStatusState"
