@@ -21,6 +21,7 @@ class UIClass(StrEnum):
     AWNING = "Awning"
     BALLAST = "Ballast"
     CAMERA = "Camera"
+    CARBON_DIOXIDE_SENSOR = "CarbonDioxideSensor"
     CAR_BUTTON_SENSOR = "CarButtonSensor"
     CIRCUIT_BREAKER = "CircuitBreaker"
     CONFIGURATION_COMPONENT = "ConfigurationComponent"
@@ -49,6 +50,7 @@ class UIClass(StrEnum):
     LIGHT = "Light"
     LIGHT_SENSOR = "LightSensor"
     MUSIC_PLAYER = "MusicPlayer"
+    NOISE_SENSOR = "NoiseSensor"
     NETWORK_COMPONENT = "NetworkComponent"
     OCCUPANCY_SENSOR = "OccupancySensor"
     ON_OFF = "OnOff"
@@ -142,6 +144,7 @@ class UIWidget(StrEnum):
     CURTAIN_TRACK_UNO = "CurtainTrackUno"
     CYCLIC_GARAGE_DOOR = "CyclicGarageDoor"
     CYCLIC_GENERIC = "CyclicGeneric"
+    CYCLIC_SWINGING_GATE_OPENER = "CyclicSwingingGateOpener "
     DHW_SET_POINT = "DHWSetPoint"
     DE_DIETRICH_BOILER = "DeDietrichBoiler"
     DE_DIETRICH_DHW = "DeDietrichDHW"
@@ -159,7 +162,7 @@ class UIWidget(StrEnum):
     DIMMER_RGBCOLOURED_LIGHT = "DimmerRGBColouredLight"
     DIMPLEX_VENTILATION_INLET_OUTLET = "DimplexVentilationInletOutlet"
     DISCRETE_EXTERIOR_HEATING = "DiscreteExteriorHeating"
-    DISCRETE_GATE_WITH_PEDESTRIAN_POSITION = "DiscreteGateWithPedestrianPosition "
+    DISCRETE_GATE_WITH_PEDESTRIAN_POSITION = "DiscreteGateWithPedestrianPosition"
     DISCRETE_POSITIONABLE_GARAGE_DOOR = "DiscretePositionableGarageDoor"
     DISCRETE_POSITIONABLE_GATE = "DiscretePositionableGate"
     DOCK = "Dock"
@@ -174,12 +177,14 @@ class UIWidget(StrEnum):
     DYNAMIC_BRIDGE = "DynamicBridge"
     DYNAMIC_CIRCUIT_BREAKER = "DynamicCircuitBreaker"
     DYNAMIC_CURTAIN = "DynamicCurtain"
+    DYNAMIC_DOMESTIC_HOT_WATER_PRODUCTION = "DynamicDomesticHotWaterProduction"
     DYNAMIC_GARAGE_DOOR = "DynamicGarageDoor"
     DYNAMIC_GATE = "DynamicGate"
     DYNAMIC_GATEWAY = "DynamicGateway"
     DYNAMIC_HEATER = "DynamicHeater"
     DYNAMIC_HUMIDITY_SENSOR = "DynamicHumiditySensor"
     DYNAMIC_HVAC_CENTRAL_UNIT = "DynamicHvacCentralUnit"
+    DYNAMIC_HVAC_ZONE = "DynamicHvacZone"
     DYNAMIC_INTRUSION_SENSOR = "DynamicIntrusionSensor"
     DYNAMIC_LIGHT = "DynamicLight"
     DYNAMIC_LIGHT_SENSOR = "DynamicLightSensor"
@@ -259,6 +264,11 @@ class UIWidget(StrEnum):
     MY_FOX_CAMERA = "MyFoxCamera"
     MY_FOX_SECURITY_CAMERA = "MyFoxSecurityCamera"
     NODE = "Node"
+    NETATMO_CONFIGURATION_COMPONENT = "NetatmoConfigurationComponent"
+    NETATMO_GATEWAY = "NetatmoGateway"
+    NETATMO_HOME = "NetatmoHome"
+    NETATMO_WEATHER_STATION_CONFIGURATION = "NetatmoWeatherStationConfiguration"
+    NOISE_SENSOR = "NoiseSensor"
     OVPGENERIC = "OVPGeneric"
     OCCUPANCY_SENSOR = "OccupancySensor"
     ON_OFF_HEATING_SYSTEM = "OnOffHeatingSystem"
@@ -403,6 +413,7 @@ class UIWidget(StrEnum):
     WEATHER_FORECAST_SENSOR = "WeatherForecastSensor"
     WIFI = "Wifi"
     WIND_SPEED_SENSOR = "WindSpeedSensor"
+    WIND_SPEED_AND_DIRECTION_SENSOR = "WindSpeedAndDirectionSensor"
     WINDOW_LOCK = "WindowLock"
     WINDOW_WITH_TILT_SENSOR = "WindowWithTiltSensor"
     ZWAVE_AEOTEC_CONFIGURATION = "ZWaveAeotecConfiguration"
