@@ -1,4 +1,5 @@
 """Utils for Overkiz client"""
+
 from __future__ import annotations
 
 import re
@@ -23,6 +24,7 @@ def obfuscate_string(input: str) -> str:
     return re.sub(r"[a-zA-Z0-9_.-]*", "*", str(input))
 
 
+# pylint: disable=too-many-branches
 def obfuscate_sensitive_data(data: dict[str, Any]) -> JSON:
     """Mask Overkiz JSON data to remove sensitive data"""
     mask_next_value = False
@@ -68,6 +70,8 @@ def obfuscate_sensitive_data(data: dict[str, Any]) -> JSON:
                     continue
                 if isinstance(val, list):
                     continue
+                if val is None:
+                    continue
 
                 obfuscate_sensitive_data(val)
 
